ete2.treeview.layouts

Package ete2 :: Package treeview :: Module layouts |
[hide private]
[frames] | no frames]

# Module layouts

source code

Functions | [hide private]
basic(node) | source code
phylogeny(node) | source code
heatmap(node) | source code
cluster_cbars(node) | source code
cluster_lines(node) | source code
cluster_bars(node) | source code
large(node) | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'``
| layout_functions = `{"Basic": basic, "Phylogenetic tree": phylo`...``
| __package__ = ``'``ete2.treeview``'``

Variables Details | [hide private]

  ### layout_functions Value:
      {"Basic": basic, "Phylogenetic tree": phylogeny, "Clustering heatmap":
       heatmap, "Clustering validation (bars)": cluster_bars, "Clustering va
      lidation (profiles)": cluster_cbars, "Very large topology": large}